=============
API reference
=============

.. currentmodule:: starsim

This page lists Starsim's full API, including all functions and classes.

.. autosummary::
   :toctree: _autosummary
   :template: custom-module-template.rst
   :recursive:
   :nosignatures:

   arrays
   calibration
   demographics
   disease
   distributions
   interventions
   loop
   modules
   networks
   parameters
   people
   products
   results
   run
   samples
   settings
   sim
   time
   utils
